summaryrefslogtreecommitdiffstats
path: root/winsup/cygwin/errno.cc
diff options
context:
space:
mode:
Diffstat (limited to 'winsup/cygwin/errno.cc')
-rw-r--r--winsup/cygwin/errno.cc6
1 files changed, 5 insertions, 1 deletions
diff --git a/winsup/cygwin/errno.cc b/winsup/cygwin/errno.cc
index c7b491cb4..3a4026077 100644
--- a/winsup/cygwin/errno.cc
+++ b/winsup/cygwin/errno.cc
@@ -283,7 +283,8 @@ extern const char __declspec(dllexport) * const _sys_errlist[]=
/* ESTALE 133 */ "Stale NFS file handle",
/* ENOTSUP 134 */ "134",
/* ENOMEDIUM 135 */ "no medium",
/* ENOSHARE 136 */ "No such host or network path"
};
int __declspec(dllexport) _sys_nerr =
@@ -659,6 +660,9 @@ strerror (int errnum)
case ENOSHARE:
error = "No such host or network path";
break;
+ case ECASECLASH:
+ error = "Filename exists with different case";
+ break;
default:
#ifdef _MT_SAFE
char *buf= _reent_winsup()->_strerror_buf;
@@ -283,7 +283,8 @@ extern const char __declspec(dllexport) * const _sys_errlist[]=
/* ENOTSUP 134 */ "134",
/* ENOMEDIUM 135 */ "no medium",
-/* ENOSHARE 136 */ "No such host or network path"
+/* ENOSHARE 136 */ "No such host or network path",
+/* ECASECLASH 137 */ "Filename exists with different case"
};
int __declspec(dllexport) _sys_nerr =